mails

package
v1.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package mails implements various helper methods for sending common emails like forgotten password, verification, etc.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SendRecordChangeEmail

func SendRecordChangeEmail(app core.App, authRecord *core.Record, newEmail string) error

SendRecordChangeEmail sends a change email confirmation email to the specified auth record.

func SendRecordVerification

func SendRecordVerification(app core.App, authRecord *core.Record) error

SendRecordVerification sends a verification request email to the specified auth record.

Types

This section is empty.

Directories

Path Synopsis

Jump to