zap

package
v1.5.49 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package zap provides a ZAP binary protocol transport for Hanzo Base.

Instead of HTTP/JSON, clients can communicate with Base using the ZAP zero-copy binary protocol for significantly lower latency and memory usage.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MustRegister

func MustRegister(app core.App)

MustRegister registers the ZAP transport plugin with a Base app. Call this before app.Start().

func MustRegisterWithConfig

func MustRegisterWithConfig(app core.App, config Config)

MustRegisterWithConfig registers the ZAP transport plugin with custom config.

Types

type Config

type Config struct {
	// Port to listen on for ZAP connections (default 9999).
	Port int

	// ServiceType for mDNS discovery (default "_hanzo-base._tcp").
	ServiceType string

	// NodeID for ZAP peer identification (default hostname-based).
	NodeID string

	// Enabled controls whether the ZAP listener starts (default true).
	Enabled bool
}

Config for the ZAP transport plugin.

func DefaultConfig

func DefaultConfig() Config

DefaultConfig returns a Config with sensible defaults.

Jump to